@@ -1,7 +1,8 @@
-from .common import Benchmark, get_squares
+from io import SEEK_SET, BytesIO, StringIO
 
 import numpy as np
-from io import StringIO
+
+from .common import Benchmark, get_squares, get_squares_
 
 
 class Copy(Benchmark):
@@ -67,6 +68,15 @@ class Savez(Benchmark):
         np.savez('tmp.npz', **self.squares)
 
 
+class LoadNpyOverhead(Benchmark):
+    def setup(self):
+        self.buffer = BytesIO()
+        np.save(self.buffer, get_squares_()['float32'])
+
+    def time_loadnpy_overhead(self):
+        self.buffer.seek(0, SEEK_SET)
+        np.load(self.buffer)
+
 class LoadtxtCSVComments(Benchmark):
     # benchmarks for np.loadtxt comment handling
     # when reading in CSV files
@@ -75,12 +85,12 @@ class LoadtxtCSVComments(Benchmark):
     param_names = ['num_lines']
 
     def setup(self, num_lines):
-        data = [u'1,2,3 # comment'] * num_lines
+        data = ['1,2,3 # comment'] * num_lines
         # unfortunately, timeit will only run setup()
         # between repeat events, but not for iterations
         # within repeats, so the StringIO object
-        # will have to be rewinded in the benchmark proper
-        self.data_comments = StringIO(u'\n'.join(data))
+        # will have to be rewound in the benchmark proper
+        self.data_comments = StringIO('\n'.join(data))
 
     def time_comment_loadtxt_csv(self, num_lines):
         # benchmark handling of lines with comments
@@ -93,7 +103,7 @@ class LoadtxtCSVComments(Benchmark):
         # confounding timing result somewhat) for every
         # call to timing test proper
         np.loadtxt(self.data_comments,
-                   delimiter=u',')
+                   delimiter=',')
         self.data_comments.seek(0)
 
 class LoadtxtCSVdtypes(Benchmark):
@@ -106,8 +116,8 @@ class LoadtxtCSVdtypes(Benchmark):
     param_names = ['dtype', 'num_lines']
 
     def setup(self, dtype, num_lines):
-        data = [u'5, 7, 888'] * num_lines
-        self.csv_data = StringIO(u'\n'.join(data))
+        data = ['5, 7, 888'] * num_lines
+        self.csv_data = StringIO('\n'.join(data))
 
     def time_loadtxt_dtypes_csv(self, dtype, num_lines):
         # benchmark loading arrays of various dtypes
@@ -117,7 +127,7 @@ class LoadtxtCSVdtypes(Benchmark):
         # rewind of StringIO object
 
         np.loadtxt(self.csv_data,
-                   delimiter=u',',
+                   delimiter=',',
                    dtype=dtype)
         self.csv_data.seek(0)
 
@@ -127,15 +137,15 @@ class LoadtxtCSVStructured(Benchmark):
 
     def setup(self):
         num_lines = 50000
-        data = [u"M, 21, 72, X, 155"] * num_lines
-        self.csv_data = StringIO(u'\n'.join(data))
+        data = ["M, 21, 72, X, 155"] * num_lines
+        self.csv_data = StringIO('\n'.join(data))
 
     def time_loadtxt_csv_struct_dtype(self):
         # obligate rewind of StringIO object
         # between iterations of a repeat:
 
         np.loadtxt(self.csv_data,
-                   delimiter=u',',
+                   delimiter=',',
                    dtype=[('category_1', 'S1'),
                           ('category_2', 'i4'),
                           ('category_3', 'f8'),
@@ -174,10 +184,10 @@ class LoadtxtReadUint64Integers(Benchmark):
 
     def setup(self, size):
         arr = np.arange(size).astype('uint64') + 2**63
-        self.data1 = StringIO(u'\n'.join(arr.astype(str).tolist()))
+        self.data1 = StringIO('\n'.join(arr.astype(str).tolist()))
         arr = arr.astype(object)
         arr[500] = -1
-        self.data2 = StringIO(u'\n'.join(arr.astype(str).tolist()))
+        self.data2 = StringIO('\n'.join(arr.astype(str).tolist()))
 
     def time_read_uint64(self, size):
         # mandatory rewind of StringIO object
@@ -200,14 +210,14 @@ class LoadtxtUseColsCSV(Benchmark):
 
     def setup(self, usecols):
         num_lines = 5000
-        data = [u'0, 1, 2, 3, 4, 5, 6, 7, 8, 9'] * num_lines
-        self.csv_data = StringIO(u'\n'.join(data))
+        data = ['0, 1, 2, 3, 4, 5, 6, 7, 8, 9'] * num_lines
+        self.csv_data = StringIO('\n'.join(data))
 
     def time_loadtxt_usecols_csv(self, usecols):
         # must rewind StringIO because of state
         # dependence of file reading
         np.loadtxt(self.csv_data,
-                   delimiter=u',',
+                   delimiter=',',
                    usecols=usecols)
         self.csv_data.seek(0)
 
@@ -225,7 +235,7 @@ class LoadtxtCSVDateTime(Benchmark):
         dates = np.arange('today', 20, dtype=np.datetime64)
         np.random.seed(123)
         values = np.random.rand(20)
-        date_line = u''
+        date_line = ''
 
         for date, value in zip(dates, values):
             date_line += (str(date) + ',' + str(value) + '\n')
@@ -238,7 +248,7 @@ class LoadtxtCSVDateTime(Benchmark):
         # rewind StringIO object -- the timing iterations
         # are state-dependent
         X = np.loadtxt(self.csv_data,
-                       delimiter=u',',
+                       delimiter=',',
                        dtype=([('dates', 'M8[us]'),
                                ('values', 'float64')]))
         self.csv_data.seek(0)
